@@ -24,6 +24,7 @@
 #include <algorithm>
 #include <functional>
 #include <iostream>
+#include <vector>
 #include <glibmm/date.h>
 #include <glibmm-utils/ustring.h>
 #include "document.hh"
@@ -161,7 +162,31 @@ namespace paperbox {
     void
     Document::set_page_count(const Glib::ustring& page_count)
     {
-        page_count_ = Glib::Util::convert_to<int>(page_count);
+        try {
+            page_count_ = Glib::Util::convert_to<int>(page_count);
+        } catch (const Glib::Util::BadConversion& ex) {
+            LOG_EXCEPTION("could not convert page count string '"
+                    << page_count << "' to an integer for document "
+                    << uri_.raw());
+            // In bugs like #552648, this would be the case of trackerd
+            // returned page count string being '119 1', '8 1' etc.
+            // So let's try to split by whitespace and try to convert
+            // whatever is the first token.
+            std::vector<Glib::ustring> tokens = Glib::Util::split(page_count);
+            if (! tokens.size()) {
+                page_count_ = 0;
+                return;
+            }
+
+            try {
+                page_count_ = Glib::Util::convert_to<int>(tokens[0]);
+                LOG_DD("after a split, page count set to " << page_count_);
+            } catch (const Glib::Util::BadConversion& ex) { // give up
+                LOG_EXCEPTION("attempt after splitting by whitespace failed, "
+                        << "setting to zero.");
+                page_count_ = 0;
+            }
+        }
     }
 
     int
@@ -173,7 +198,15 @@ namespace paperbox {
     void
     Document::set_word_count(const Glib::ustring& word_count)
     {
-        word_count_ = Glib::Util::convert_to<int>(word_count);
+        try {
+            word_count_ = Glib::Util::convert_to<int>(word_count);
+        } catch (const Glib::Util::BadConversion& ex) {
+            // no special handling here, as there have been no reports yet
+            LOG_EXCEPTION("could not convert word count string '"
+                    << word_count << "' to integer, setting to zero for "
+                    << "document " << uri_.raw());
+            word_count_ = 0;
+        }
     }
 
     Glib::ustring
